import java.awt.event.*;
import java.util.*;

/**
 * Lab #5
 * CS 2334, Section SECTION NUMBER GOES HERE
 * DATE GOES HERE
 * <p>
 * Each object of this class represents a GUI enhanced model of an Olympic team.
 * The model of an MVC GUI.
 * </p>
 * @version 1.0
 *
 */
public class OlympicTeamModel extends OlympicTeam {

	/**
	 * List to keep track of who is registered to listen for events from the OlympicTeamModel.
	 */
	private ArrayList<ActionListener> actionListenerList;
	
	/**
	 * @param country
	 */
	public OlympicTeamModel(String country) {
		super(country);
	}

	/**
	 * @param country
	 * @param roster
	 */
	public OlympicTeamModel(String country, LinkedHashMap<String, OlympicAthlete> roster) {
		super(country, roster);
	}
	
	/**
	 * @param athlete
	 */
	public void addToRoster(OlympicAthlete athlete) {
		super.addToRoster(athlete);
		processEvent(new ActionEvent(this, ActionEvent.ACTION_PERFORMED, "add athlete"));
	}
	
	
	public void clearRoster() {
		super.clearRoster();
		processEvent(new ActionEvent(this, ActionEvent.ACTION_PERFORMED, "clear roster"));
	}
	
	/**
	 * Register an action event listener.
	 */
	public synchronized void addActionListener(ActionListener l) {
		if (actionListenerList == null)
			actionListenerList = new ArrayList<ActionListener>();
		actionListenerList.add(l);
	}
	
	/**
	 * Remove an action event listener.
	 */
	public synchronized void removeActionListener(ActionListener l) {
		if (actionListenerList != null && actionListenerList.contains(l))
			actionListenerList.remove(l);
	}
	
	/**
	 * Fire event.
	 */
	private void processEvent(ActionEvent e) {
		ArrayList<ActionListener> list;
		
		synchronized (this) {
			if (actionListenerList == null) return;
			list = (ArrayList<ActionListener>)actionListenerList.clone();
		}
		
		for (int i = 0; i < list.size(); i++) {
			ActionListener listener = list.get(i);
			listener.actionPerformed(e);
		}
	}
}